California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 55 - KINDERGARTEN-UNIVERSITY PUBLIC EDUCATION FACILITIES BOND ACT OF 2004. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1220380 | COMMUNITY COLLEGE FACILITY COALITION ISSUES COMMITTEE, YES ON 55 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1245448 | YES ON 55 -- CALIFORNIANS FOR ACCOUNTABILITY AND BETTER SCHOOLS, A COALITION OF TAXPAYERS, PARENTS, SENIORS, EDUCATORS, BUILDERS, LABOR AND BUSINESS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
900868 | CALIFORNIA BUILDING INDUSTRY ASSOCIATION ISSUES PAC | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
980478 | COALITION FOR ADEQUATE SCHOOL HOUSING ISSUES COMMITTEE, YES ON 55 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1224009 | CALIFORNIANS FOR HIGHER EDUCATION, YES ON 55 | SUPPORT